CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended Modules
* Installation
* Configuration
* Maintainers


INTRODUCTION
------------

The image sizes module extends responsive image styles with a new option which
uses container based sizing instead of mediaQuery based sizing. This will have
positive impact on your Google page speed rank.

It does so by adding a browser native srcset. A resize observer sets the sizes
attribute dynamically. Thus, the browser can choose the correct image by itself.
This also allows works with different DPI values. Just make sure that you preset
is large enough.
E.g. If the image can be max 600px on your page then you should go up to
1200px width to support 2x dpi screens.

In addition to this, a drush command is provided which generates the required
configuration for you in no time.


REQUIREMENTS
------------

This module requires the following modules:

* Responsive image (core)
* Form decorator - https://www.drupal.org/project/form_decorator


RECOMMENDED MODULES
-------------------

* Media Responsive Thumbnail - https://www.drupal.org/project/media_responsive_thumbnail


INSTALLATION
------------

* Install as you would normally install a contributed Drupal module. Visit
  https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

There are two ways on how to configure image sizes.
1. Through the **UI**
   Since image sizes is based on the responsive image module, configuring it
   works just the same.
  1. Go to /admin/config/media/responsive-image-style
  2. Create a new responsive image style
  3. Select "Image sizes" from the "Breakpoint group" selection
  4. Select all the image styles you want to use for your configuration. They
     should be using the same aspect ratio.
  5. Select a preload style and a fallback style.
  6. Save
  7. Go to your image field and select "Responsive image" as a formatter and
     select the created style.
2. Using **Drush**
```
# Generate a preset with name default without a ratio.
drush isg "Default" 100 1400 100

# Add a blurred placeholder.
drush isg "Default" 100 1400 100 --generate-thumbnail

# Generate style with 4x3 ratio.
drush isg "Default" 100 1400 100 --ratio=4x3

# Generate style with 4x3 ratio with focal point. Works only with ratio option.
drush isg "Default" 100 1400 100 --ratio=4x3 --use-focal-point

# Generate style with 4x3 ratio with image_widget_crop. Works only with ratio
# option.
drush isg "Default" 100 1400 100 --ratio=4x3 --use-manual-crop

# Convert to png file. Default is webp.
drush isg "Default" 100 1400 100 --format=png
```


UPGRADE FROM 3.x to 4.x
-------------

Version 4 of the image sizes module has been rewritten to base on drupal core's
responsive_image module instead of providing a similar custom entity and
formatter. This allows us to make use of the functionality and ecosystem around
it.

To upgrade from version 3 to version 4, just update the image_sizes module and
execute update.php or `drush updb`. Your existing image_sizes configuration will
be updated to responsive_image configuration and your formatters as well.

If you are using image sizes on media fields, you need to install the
[Media Responsive Thumbnail](https://www.drupal.org/project/media_responsive_thumbnail)
module in addition.


KNOWN ISSUES
-----------

* The preload image style width and height are used for the aspect ratio. This
  can cause slight layout shift when using image presets without fixed aspect
  ratios.


MAINTAINERS
-----------

Current maintainers:
* Pascal Crott - https://www.drupal.org/u/hydra

Former maintainers:
* Erik Seifert - https://www.drupal.org/u/erik-seifert
* woldtwerk - https://www.drupal.org/u/woldtwerk (image_sizes_extras module)


SUPPORTING ORGANIZATIONS
-----------

* [erdfisch](https://www.drupal.org/erdfisch) (version 4 and maintenance)
* [WERTGARANTIE Bike GmbH](https://www.drupal.org/wertgarantie-bike-gmbh) (bugfixes)
* [Oliver Schrott Kommunikation GmbH](https://www.drupal.org/oliver-schrott-kommunikation-gmbh) (former maintenance)
* [UEBERBIT GmbH](https://www.drupal.org/ueberbit-gmbh) (image_sizes_extras module)
