<?php

namespace Drupal\image_sizes_upgrade\Entity;

use Drupal\image\Entity\ImageStyle;
use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Image sizes preset entity.
 *
 * @ConfigEntityType(
 *   id = "image_sizes_preset_entity",
 *   label = @Translation("Image sizes preset"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\image_sizes_upgrade\ImageSizesPresetEntityListBuilder",
 *     "storage" = "Drupal\image_sizes_upgrade\ImageSizesPresetEntityStorage",
 *     "form" = {
 *       "add" = "Drupal\image_sizes_upgrade\Form\ImageSizesPresetEntityForm",
 *       "edit" = "Drupal\image_sizes_upgrade\Form\ImageSizesPresetEntityForm",
 *       "delete" = "Drupal\image_sizes_upgrade\Form\ImageSizesPresetEntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\image_sizes_upgrade\ImageSizesPresetEntityHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "image_sizes_preset_entity",
 *   config_export = {
 *     "id",
 *     "label",
 *     "uuid",
 *     "fallback",
 *     "styles",
 *     "preload"
 *   },
 *   admin_permission = "administer image sizes",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/media/image_sizes_preset_entity/{image_sizes_preset_entity}",
 *     "add-form" = "/admin/config/media/image_sizes_preset_entity/add",
 *     "edit-form" = "/admin/config/media/image_sizes_preset_entity/{image_sizes_preset_entity}/edit",
 *     "delete-form" = "/admin/config/media/image_sizes_preset_entity/{image_sizes_preset_entity}/delete",
 *     "collection" = "/admin/config/media/image_sizes_preset_entity"
 *   }
 * )
 */
class ImageSizesPresetEntity extends ConfigEntityBase implements ImageSizesPresetEntityInterface {

  /**
   * The Image sizes preset entity ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Image sizes preset entity label.
   *
   * @var string
   */
  protected $label;

  /**
   * The Image fallback style.
   *
   * @var string
   */
  protected $fallback;

  /**
   * The Image styles.
   *
   * @var string[]
   */
  protected $styles = [];

  /**
   * The Image preload styles.
   *
   * @var string[]
   */
  protected $preload;

  /**
   * {@inheritdoc}
   */
  public function setFallbackStyle($fallback) {
    $this->fallback = $fallback;
  }

  /**
   * {@inheritdoc}
   */
  public function getFallbackStyle() {
    return $this->fallback;
  }

  /**
   * {@inheritdoc}
   */
  public function setPreloadStyle($preload) {
    $this->preload = $preload;
  }

  /**
   * {@inheritdoc}
   */
  public function getPreloadStyle() {
    return $this->preload;
  }

  /**
   * {@inheritdoc}
   */
  public function setStyles(array $styles) {
    $this->styles = $styles;
  }

  /**
   * {@inheritdoc}
   */
  public function getStyles() {
    return $this->styles;
  }

  /**
   * {@inheritdoc}
   */
  public function addStyle($style) {
    if (!in_array($style, $this->styles)) {
      $this->styles[$style] = $style;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function removeStyle($style) {
    if (in_array($style, $this->styles)) {
      unset($this->styles[array_search($style, $this->styles)]);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    parent::calculateDependencies();
    $styles = $this->styles;
    if ($this->fallback) {
      $styles[] = $this->fallback;
    }
    if ($this->preload) {
      $styles[] = $this->preload;
    }

    parent::calculateDependencies();

    $styles = ImageStyle::loadMultiple($styles);
    array_walk($styles, function ($style) {
      $this->addDependency('config', $style->getConfigDependencyName());
    });
    return $this;
  }

}
