<?php

declare(strict_types=1);

namespace Drupal\image_sizes\Entity;

use Drupal\responsive_image\Entity\ResponsiveImageStyle as ResponsiveImageStyleCore;

/**
 * Extend the responsive image style entity to support image_sizes approach.
 */
class ResponsiveImageStyle extends ResponsiveImageStyleCore implements ResponsiveImageStyleImageSizesInterface {

  /**
   * Tracks if the image style mapping reoval has already been executed.
   *
   * @var bool
   *   TRUE if already executed.
   */
  protected $removedImageStyleMappings = FALSE;

  /**
   * {@inheritdoc}
   */
  public function getPreloadImageStyle(): string {
    return $this->getImageStyleMapping('image_sizes.sizing', '1x')['image_mapping']['preload'] ?? '';
  }

  /**
   * {@inheritdoc}
   */
  public function removeImageStyleMappings() {
    // Prevent removing the options twice, since we want to add additional save
    // operations and need to alter this therefore.
    if (!$this->removedImageStyleMappings) {
      $this->removedImageStyleMappings = TRUE;
      return parent::removeImageStyleMappings();
    }

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function isEmptyImageStyleMapping(array $image_style_mapping) {
    if (!empty($image_style_mapping)) {
      switch ($image_style_mapping['image_mapping_type']) {
        case 'image_sizes':
          // The image style mapping must have an image style selected.
          if ($image_style_mapping['image_mapping']) {
            return FALSE;
          }
          break;
      }
    }

    return parent::isEmptyImageStyleMapping($image_style_mapping);
  }

  /**
   * {@inheritdoc}
   */
  public function getImageStyleIds() {
    foreach ($this->getImageStyleMappings() as $image_style_mapping) {
      // Only image styles of non-empty mappings should be loaded.
      if (!$this::isEmptyImageStyleMapping($image_style_mapping)) {
        switch ($image_style_mapping['image_mapping_type']) {
          case 'image_sizes':
            return array_values(array_filter(array_unique($image_style_mapping['image_mapping']['sizes_image_styles'])));
        }
      }
    }

    return parent::getImageStyleIds();
  }

}
